@@ -776,6 +776,7 @@ void help (void)
 int main (int argc, char *argv[])
 {
   int i;
+  DIR *dir;
   char zw[MAXPATHLEN];
   char resolv_name[MAXPATHLEN];
 
@@ -794,6 +795,14 @@ int main (int argc, char *argv[])
   }
   else
   {
+    if ((dir = opendir (DOCDIR)) == NULL)
+    {
+       fprintf (stderr, "dhelp_parse: I can't open %s, the package "
+               "documentation won't be registered. It's non-fatal.\n\n", DOCDIR);
+       return (0);    /* do not break postinst/postrm scripts */
+    }
+    closedir (dir);
+
     mkdir ("/var/lib/dhelp/", 0755);
     for (i=2; i < argc; i++)
     { 
